#
# spec file for package retro-gtk
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use of library versioning and name versioning macros to facilitate updatings
%define namever 1-0
%define libver  1

Name:           retro-gtk
Version:        1.0.2
Release:        2.9
Summary:        Toolkit to write Gtk+3-based frontends to libretro
License:        GPL-3.0-only
Group:          System/GUI/GNOME
URL:            https://git.gnome.org/browse/retro-gtk
Source0:        https://download.gnome.org/sources/%{name}/1.0/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM fix-meson-build-failure.patch -- luc14n0@opensuse.org
# based on commit 8016c10e7216394bc66281f2d9be740140b6fad6.
# Fix pkg.generate() that got "export_packages" and "namespace"
# keyword arguments removed in Meson 0.60 release.
Patch0001:      0001-Retro-GTK-1.0.2-fix-meson-build-failure.patch

BuildRequires:  gobject-introspection-devel >= 0.6.7
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(vapigen)

%description
retro-gtk wraps the libretro API for use in Gtk applications such as
GNOME Games.

%package -n libretro-gtk-%{namever}
Summary:        Toolkit to write Gtk+3-based frontends to libretro
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libretro-gtk-%{namever}
retro-gtk wraps the libretro API for use in Gtk applications such as
GNOME Games.
(libretro is an API specification implemented by some emulator
libraries like libretro-bsnes.)

%package -n typelib-1_0-Retro-%{namever}
Summary:        GObject introspection bindings for libretro-gtk
Group:          System/Libraries

%description -n typelib-1_0-Retro-%{namever}
retro-gtk wraps the libretro API for use in Gtk applications.
This subpackage contains the gobject bindings for the
libretro-gtk shared library.

%package devel
Summary:        Development files for retro-gtk, a Gtk+3 wrapper for libretro
Group:          Development/Languages/C and C++
Requires:       libretro-gtk-%{namever} = %{version}
Requires:       typelib-1_0-Retro-%{namever} = %{version}

%description devel
retro-gtk wraps the libretro API for use in Gtk applications.
This subpackage contains the headers to make use of the libretro-gtk
library.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
# make install copies AUTHORS, COPYING et.al to doc/%%{name}
# we capture them using the %%doc macro
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post   -n libretro-gtk-%{namever} -p /sbin/ldconfig
%postun -n libretro-gtk-%{namever} -p /sbin/ldconfig

%files
%{_libexecdir}/retro-runner

%files -n libretro-gtk-%{namever}
%license COPYING
%doc AUTHORS NEWS
%{_libdir}/libretro-gtk-%{libver}.so.0

%files -n typelib-1_0-Retro-%{namever}
%{_libdir}/girepository-1.0/Retro-%{libver}.typelib

%files devel
%{_bindir}/retro-demo
%{_datadir}/gir-1.0/Retro-%{libver}.gir
%{_datadir}/vala/vapi/retro-gtk-%{libver}.deps
%{_datadir}/vala/vapi/retro-gtk-%{libver}.vapi
%{_libdir}/pkgconfig/retro-gtk-%{libver}.pc
%{_includedir}/retro-gtk/
%{_libdir}/libretro-gtk-%{libver}.so

%changelog
* Mon Jan 10 2022 Luciano Santos <luc14n0@opensuse.org>
- Add upstream 0001-Retro-GTK-1.0.2-fix-meson-build-failure.patch
  based on commit 8016c10e7216394bc66281f2d9be740140b6fad6 to fix
  pkg.generate() that got "export_packages" and "namespace" keyword
  arguments removed in Meson 0.60 release.
* Mon Mar 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.2:
  + RetroCoreDescriptor: Propagate an accidentally unhandled error.
  + Implement mouse buttons 4 and 5.
  + Fix the GLES context initialization.
  + Drop the code making temporary copies of the core to avoid
    static variable collisions, this isn't needed anymore as such
    collisions can't happen since a single instance of a core is
    used per subprocess.
  + Many code style cleanups.
* Sun Nov 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.1:
  + RetroCoreView: Add the key press, key release and touch event
    masks to ensure it receives all the events it can handle, and
    hence to ensure that these input methods work as expected.
  + Meson: Add the vapi option to allow disabling building Vala
    bindings.
  + Documentation:
  - Add the Libretro Core Descriptor Specification 1.0 section.
  - Add the Retro Reference Test Case Specification 1.0 section.
  + Clean up the documentation, README.md, HACKING.md,
    retro-gtk.doap, .editorconfig, update-from-retroarch, the Meson
    files, and more.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 1.0.0:
  + Major API overhaul and API version bump, detailing all the
    changes would be ridiculous and hence won't be done.
  + Run Libretro cores isolated in a dedicated subprocess,
    similarly to how modern web browsers handle web pages.
  + Support Libretro cores rendering their video with OpenGL.
  + Improve the Libretro core timing accuracy.
  + Resample the Libretro core's audio output to ensure it matches
    its play speed.
- Package the new retro-runner in the main package. The library
  requires this to be present.
- Add pkgconfig(samplerate) BuildRequires: new dependency.
* Sun Jan 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.18.1:
  + Meson:
  - Bump the required version to 0.50.0 to fix a
    build-time-warning.
  - Explicitly specify the GIR namespace and the packages GIR
    exports.
  + RetroGLDisplay: Scale coordinates on display for pointer inputs
    to work in Hi-DPI.
  + Register a GType for RetroRumbleEffect.
* Thu Sep 12 2019 mgorse@suse.com
- Update to version 0.18.0:
  + Pixbufs:
  - Add retro_pixbuf_set_aspect_ratio() for embedding aspect
    ratio value to a GdkPixbuf.
  - Add retro_pixbuf_get_aspect_ratio() for retrieving the value
    set with retro_pixbuf_set_aspect_ratio().
  - Deprecate x-dpi and y-dpi metadata options.
  + RetroCoreView:
  - Take pixbuf aspect ratio into account when drawing a
    standalone pixbuf instead of using aspect ratio of the
    current core.
  + Fix build on Fedora 30.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.16.1:
  + RetroCoreView: Support RETRO_CONTROLLER_TYPE_KEYBOARD.
  + RetroCore: Bufferize single audio frames to emit them as
    batches for better performances.
  + Add CSS names to widgets.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 0.16.0:
  + Update README.md.
* Mon Jul 30 2018 bjorn.lie@gmail.com
- Update to version 0.15.90:
  + RetroMainLoop:
  - Lower the priority of the loop to prevent a lagging game from
    freezing the rendering of its video.
  - Prevent reference leaking when destroying the loop while it's
    not stopped by not giving a reference to the loop's callback.
  + RetroGLDisplay: Take the UI's scale into account, making it
    usable in Hi-DPI.
  + Prepare RetroGLDisplay for GTK+ 4:
  - Don't clear depth buffer as we don't use it and as this would
    cause glitches in GTK+ 4.
  - Explicitly use glClearColor().
  - Call glBindTexture() on every frame to ensure that we're
    always working with the right texture, which is needed for
    GTK+ 4.
  + Fix reference cycles in retro-demo to avoid memory leaks.
* Sat Jul 28 2018 bjorn.lie@gmail.com
- Update to version 0.15.3:
  + Build:
  - Replace the Autotools by Meson.
  - Replace intltool for gettext.
  - Replace the update-gameinfo build target by the
    update-gameinfo.sh script.
  - Add a development profile, settable by passing the
    `-Dprofile=development` parameter to Meson. This profile
    makes it clear the application is a development version by
    appending ` (Development)` to the application name, by
    appending `Devel` to the application ID, by changing the
    style of the header bar and by appending the commit tag or
    `-devel` to the version number.
  + UI:
  - Allow to set the keyboard to gamepad mapping from the
    preferences Controllers page.
  - Make searching for local covers less greedy and asynchronous,
    speeding up the loading time of the collection.
  - Move the application menu to the collection view's header
    bar.
  - Add the Help application menu entry, opening Games'
    documentation on the GNOME wiki.
  - Add the Shortcuts application menu entry displaying a
    shortcuts window.
  - Display small thumbnails if the window is narrow to display
    more of games.
  - Correctly update the selected media number on the media
    selector.
  - Drop the shadow in the collection view's scrolled window.
  + Libretro backend:
  - Add support for .options keyfiles listing options to be set
    on a Libretro core at initialization time.
  - Add predefined options for DeSmuME and DeSmuME 2015.
  + Supported games:
  - Add support for Virtual Boy games.
  - Use a dedicated MIME type for Neo Geo Pocket Color instead of
    the Neo Geo Pocket one.
  - Use a phony TurboGrafx-CD MIME type to fetch information from
    Grilo.
  + Allow to read cue sheets in other formats than UTF-8, avoiding
    the application to crash when parsing a file in UTF-16 or other
    encoding.
  + Update the authors lists.
  + Update the appdata to the latest specifications, OARS metadata
    and update gitlab links.
  + Updated translations.
- Bump namever define to 0_14-0 following upstreams changes.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 0.14.0:
  + Add dependency on libepoxy.
  + RetroCoreView:
  - Render the video with OpenGL instead of Cairo.
  - Drop the 'pixbuf' property, but keep the pixbuf accessor
    functions.
  - Grab the focus when clicked, avoiding to miss the player's
    keyboard events to control the game.
  - Allow it to be the default widget by default bt setting the
    'can-default' property to TRUE on construction.
  + Add internal support for GLSL based video filters and port the
    existing ones to GLSL so they can work with the OpenGL
    renderer.
  + Add RETRO_VIDEO_FILTER_CRT, a RetroVideoFilter demanding the
    video display to mimick a CRT TV screen.
  + RetroPixdata:
  - Add retro_pixdata_get_width/height() and
    retro_pixdata_load_gl_texture(), allowing to export the pixel
    data to an OpenGL texture and to draw it at the expected
    size.
  - Don't fail when constructing with a non-zero rowstride, as
    these are valid values.
  + Add the set_rumble_state() virtual method to RetroController
    and implement it in RetroCoreViewController.
  + Build system change: make retro-gtk-demo properly depend on
    retro-gtk.
  + Bugs fixed: bgo#790454.
- Add pkgconfig(epoxy) BuildRequires: new dependency.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Nov 13 2017 luc14n0@linuxmail.org
- Update to version 0.13.2:
  + Port the build system to Meson, requiring version 0.43.0 and
    drop the Autotools.
  + Drop retro_core_remove_controller(), to remove a controller
    instead set it to NULL.
  + Make retro_core_poll_controllers(),
    retro_core_get_controller_input_state() and
    retro_core_get_controller_capabilities() private as they are
    meant to be used by the Libretro core and not the end users.
  + Add:
  - retro_core_set_default_controller() to set controllers to be
    used by default when there is no controller with the
    requested capability in the requested port.
  - retro_core_view_set_as_default_controller() to easily set the
    controllers of a RetroCoreView as the default controllers of
    a RetroCore. retro-demo now uses these.
  - retro_controller_has_capability() to easily check if a
    controller has the given RetroControllerType capability.
  - Add RetroInput to encapsulate the inputs used in an input
    state query. It is used in retro_controller_get_input_state()
    and retro_core_view_get_input_state().
  - Add a count enumeration value to RetroControllerType and the
    various controller code enumerations.
  + Replace gboolean by bool in get_variable_update() to avoid
    crashes.
  + Better check the creation of the PuleAudio sound output to
    avoid crashes.
- Replace configure, make, make_install macros by meson,
  meson_build and meson_install macros following upstream port to
  Meson Build System.
- Rename library from libretro-gtk0 to libretro-gtk-0_14 since
  upstream dropped libretro-gtk.so and replaced libretro-gtk.so.0
  by libretro-gtk-0.14.so
- Drop intltool BuildRequires: it's not needed since retro-gtk do
  not use translations.
- Add %%namever and %%libver macros to facilitate updatings.
* Mon Oct 16 2017 adrien.plazas@suse.com
- Update to version 0.13.1:
  + This version ports retro-gtk from Vala to C and simnplifies the
    API a lot. It comes with lots of API breaks, so many that it
    would be simpler to list what remained similar to the 0.12
    branch than what changed.
  + The API will keep changing during the 0.14 development cycle,
    but it is hoped to lead to less API breaks after that.
- Replace BuildRequires vala with BuildRequires pkgconfig(vapigen)
  as retro-gtk is now a C library compiling a VAPI.
- Rename subpackage typelib-1_0-Retro-0_12 to
  typelib-1_0-Retro-0_14 following upstream changes.
* Tue Oct  3 2017 zaitor@opensuse.org
- Drop no longer used tar scm service, upstream releases tarballs
  now.
* Mon Oct  2 2017 aplazas@suse.com
- Update to version 0.12.1:
  + Core:
  - Fix a memory leak in the destructor.
  - Support partially setting memory regions.
  + CoreView: Reset inputs when losing focus.
* Mon Sep 11 2017 aplazas@suse.com
- Update to version 0.12.0:
  + CoreViewInputDevice: Don't log errors when 'view' is NULL.
  + GameInfo: Remove some free to avoid uselessly trying to free an
    already freed RetroGameInfo.
* Mon Sep  4 2017 aplazas@suse.com
- Update to version 0.11.92:
  + Core:
  - Remove the barely used system-info property.
  - Use Gdk.EventKey for keyboard inputs.
  - Make the init singal an error-throwing method.
  - Implement disk handling directly.
  + CoreView can be exposed as a joypad, a mouse or a pointer.
  + retro-demo: add pointer support from CoreView.
  + Make all error domains internal.
  + Make internal and port to C:
  - GameInfo.
  - Module.
  - SystemAvInfo.
  - SystemInfo.
  - most of Core.
  - keyboard keys.
  + Remove unused symbols:
  - DiskControl.
  - GamepadConfiguration.
  - GamepadButtonType.
  - Keyboard.
  - KeyboardState.
  - MemDesc.
  - MemoryDescriptor.
  - MemoryMap.
  - Mouse.
  - VirtualGamepad.
  - get_system_info ().
  - SNES specific memory types from MemoryType.
* Mon Jul 17 2017 aplazas@suse.com
- Update to version 0.11.4.1:
  + A demo application has been added, it allows to directly test
    the without the need of an external tool.
  + Loading games:
  - Add the set_medias(), load_medias() and set_current_media()
    methods to Core and load the given medias (if any) in
    Core.init().
  - Remove load_game() and prepare() Core methods from the
    public API as they are now used indirectly.
  - This should simplify loading games for the users of the
    library.
  + Logging:
  - Add the Core.log() signal which will emit a GLib compatible
    logging message with the Libretro core's name as the log
    domain.
  - Add retro_g_log() to simply handle Core.log() by outputing
    the logs in the expected unstructured GLib fashion.
  - Remove LogLevel, Log and FileStreamLog as they are now
    useless.
  + Add CoreView as a prototype of a single widget to handle most
    inputs and outputs of a core and use it in the demo.
  + Add CoreDescriptor.get_uri().
  + Make CairoDisplay.set_core() and Make PaPlayer.set_core()
    accept null.
  + Fix the transmission of keyboard events to the Libretro core.
  + Rotation and many methods of Core are ported to C.
- Rename subpackage typelib-1_0-Retro-0_10 to
  typelib-1_0-Retro-0_12 following upstream changes.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 0.10.0:
  + Save the expected ratio as DPI of the video frames.
  + Bugs fixed: bgo#769833, bgo#779924, bgo#779987.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 0.9.92:
  + Allow recursive iteration through Libretro cores of a
    directory.
- Drop _service: upstream publishes proper tarballs now.
- Drop libtool BuildRequires and no longer call autogen.sh: no
  longer needed since we use a botstrapped tarball.
* Tue Feb 28 2017 adrien.plazas@suse.com
- Update to version 0.9.91:
  + Deduplicate some documentation.
  + Add missing MouseId values.
  + Remove deprecated input device types.
  + Allow core descriptors to check the firmwares.
  + Add an helper method to core descriptors tocheck the supported
    MIME types.
  + Add a module iterator, allowing sync and async module browsing.
  + Remove the now useless foreach function to browse the modules.
  + Add methods to Core to handle standalone cores more easily.
  + Fix an integer division when computing the aspect ratio.
  + Add a script to update libretro.h.
- Remove retro-gtk-fix-build-deps.patch as it already is in the new
  sources.
* Tue Feb 14 2017 adrien.plazas@suse.com
- Update to version 0.9.90:
  + Merge the retro-gobject module into retro-gtk.
  + Merge the RetroGtk namespace into Retro.
  + Remove many unused types and functions.
  + Refactor many types and functions.
  + Make the API overall simpler.
  + Search modules from their Libretro Core Descriptor.
  + Search Libretro modules in paths from the LIBRETRO_PLUGIN_PATH
    env variable.
  + Drop the ancient module query mechanisms.
  + Drop the ancient Libretro core path env variable.
  + Allow to set a smooth or sharp rendering to CairoDisplay.
- Drop libretro-gobject0 and typelib-1_0-Retro-0_0 subpackage:
  functionality has been merged into the Gtk parts.
- Rename typelib-1_0-RetroGtk-0_8 subpackage to
  typelib-1_0-RetroGtk-0_10, following upstream.
- Add retro-gtk-fix-build-deps.patch which ensures the internal
  header is compiled before the files using it.
* Fri Sep 23 2016 jengelh@inai.de
- Improve the description and summary.
* Wed Sep 21 2016 dimstar@opensuse.org
- Initial package, version 0.8.1.
